function dm2 = Gold_dm2(M,ms)
%function dm2 = Gold_dm2(M,ms)
%Returns delta-mu-squared as defined in Goldstein et al (1995) PNAS 92, 6723-6727, for all pairwise pop comps.
% dm2 = (muA-muB)^2, where muA and muB are the mean MS rpt sizes in pops A & B at a given locus.
% when information from >1 locus is available, dm2 can be averaged over loci
%If r=STR single stepwise mutation rate, then E(t)=dm2/(2r), where t=time since split of 2 pops.
%M is an nhap x npop matrix of haplotype counts in each pop
%ms is an nhap x nloci loci of repeat sizes for each haplotype.
%dm2 is based on the difference in population means, so a 'biasflag' option would be meaningless - there is no bias


[nhap,npop]=size(M);
[nhap,nloc]=size(ms);
m = M./(ones(nhap,1)*sum(M));

%Calculate nloc x npop matrix of means for each locus in each pop.
mSTR = ms'*m;

npairs=npop*(npop-1)/2;
dm2=zeros(npairs,1);

counter=0;
for i=2:npop
for j=1:i-1
  counter=counter+1;
  dm2(counter) = mean( (mSTR(:,i)-mSTR(:,j)).^2 );
end
end

