function Fst = Lat_Fst(M,biasflag);
%function Fst = Lat_Fst(M,biasflag);
%Returns unbiased Latter's Fst (Nei Eq 9.36, p.224)
%  M has vectors of haplotype counts
%  if 'biasflag' is set >0, the biased version of the statistic is returned.
%  if npop>2, I is a vector of pairwise comps taken row-wise from bottom-left triangle.

[nhap,npop]=size(M);
N=sum(M);
npairs=npop*(npop-1)/2;

Fst=zeros(npairs,1);
counter=0;
for i=2:npop
for j=1:i-1
  counter=counter+1;
  Jx = (sum(M(:,i).^2)/N(i) -1)/(N(i)-1);
  Jy = (sum(M(:,j).^2)/N(j) -1)/(N(j)-1);
  if nargin>1,  if biasflag>0
     Jx = sum(M(:,i).^2)/N(i)/N(i);
     Jy = sum(M(:,j).^2)/N(j)/N(j);
  end,  end
  Jxy = sum(M(:,i).*M(:,j))/N(i)/N(j);

  Fst(counter) = ( (Jx+Jy)/2 - Jxy ) / (1-Jxy);
end
end
