function [DA,bias] = Nei_DA(M);
%function [DA,bias] = Nei_DA(M);
%Returns unbiased Nei's DA (Nei Eq 9.16, p.216)
%Simulations (e.g. Takezaki & Nei 1996) suggest this measure recovers tree topologies well.
%  M has vectors of haplotype counts
%  'bias' is the TM estimation of the degree of bias.
%  if npop>2, I is a vector of pairwise comps taken row-wise from bottom-left triangle.

[nhap,npop]=size(M);
N=sum(M);
npairs=npop*(npop-1)/2;

DA=zeros(npairs,1);
bias=zeros(npairs,1);
counter=0;
for i=2:npop
for j=1:i-1
  counter=counter+1;
  x=M(:,i)/N(i); y=M(:,j)/N(j);
  DA(counter) = 1 - sum( sqrt(x.*y) );

%The following transformation (0->1) ensures the 0 bias contribution of zero-freq haplotypes.
  bias(counter) = sum( sqrt(x./(y+(y==0))).*(1-y-(y==0)) )./(8*N(j)) ...
                + sum( sqrt(y./(x+(x==0))).*(1-x-(x==0)) )./(8*N(i));
end
end
