function Gst = Nei_Gst(M,biasflag);
%function Gst = Nei_Gst(M,biasflag);
%Returns unbiased Nei's 2-pop Gst (1987, 153-166 and 187-192) for all pairwise comparisons
%  M has vectors of haplotype counts
%  if 'biasflag' is set >0, the biased version of the statistic is returned.
%  if npop>2, I is a vector of pairwise comps taken row-wise from bottom-left triangle.
%
%Unbiased formulae come from p.191 (applies to haploid data), except this assumes n equal in all sub-pops.
%However, comparison with formulae on p.164 indicates the harmonic mean is appropriate if this is not the case.

[nhap,npop]=size(M);
N=sum(M);
npairs=npop*(npop-1)/2;

Gst=zeros(npairs,1);
counter=0;
for i=2:npop
for j=1:i-1
  counter=counter+1;
  Nx=N(i); x = M(:,i)./Nx;
  Ny=N(j); y = M(:,j)./Ny;
  xymean = (x+y)./2;
  hx= 1 - sum(x.*x);
  hy= 1 - sum(y.*y);
  nharm = 2 / (1/Nx + 1/Ny);
  Hs = nharm/(nharm-1) * (hx+hy)/2;
  Ht = 1 - sum(xymean.*xymean) + Hs/(2*nharm);
  if nargin>1,  if biasflag>0
    Hs = (hx+hy)/2;
    Ht = 1 - sum(xymean.*xymean);
  end, end

  Gst(counter) = (Ht-Hs)/Ht;
end
end
