function I = Nei_I(M,biasflag);
%function I = Nei_I(M,biasflag);
%Returns unbiased Nei's I (Nei Eq 9.35, p.224)
%  M has vectors of haplotype counts
%  if 'biasflag' is set >0, the biased version of the statistic is returned.
%  if npop>2, I is a vector of pairwise comps taken row-wise from bottom-left triangle.

if nargin<2, biasflag=0; end

[nhap,npop]=size(M);
N=sum(M);
npairs=npop*(npop-1)/2;

I=zeros(npairs,1);
counter=0;
for i=2:npop
for j=1:i-1
  counter=counter+1;
  if biasflag>0
     Jx = sum(M(:,i).^2)/N(i)/N(i);
     Jy = sum(M(:,j).^2)/N(j)/N(j);
  else
    Jx = (sum(M(:,i).^2)/N(i) -1)/(N(i)-1);
    Jy = (sum(M(:,j).^2)/N(j) -1)/(N(j)-1);
  end
  I(counter) = sum(M(:,i).*M(:,j))/N(i)/N(j) / sqrt(Jx*Jy);
end
end
