function [h,varh] = Nei_h(M,biasflag);
%function [h,varh] = Nei_h(M,biasflag);
%Returns unbiased h (Nei Eq 8.4, p.178) and var(h) (Nei Eq 8.12, p.180)
%  M is a vector of haplotype counts, or matrix with pops in columns
% if 'biasflag' is set >0, the biased version of the statistic is returned.

if nargin<2, biasflag=0; end

N=sum(M);

biasedh = 1 - sum(M.^2)./N./N;
if biasflag>0
  h = biasedh;
else
  h = biasedh ./ (1 - 1.0 ./N);
end

if nargout>1
  [nhap,npop]=size(M);
  m = M./(ones(nhap,1)*N);
  varh = 2 ./N ./(N-1) .* ( 2 .*(N-2).*(sum(m.^3)-sum(m.^2).^2) + sum(m.^2) - sum(m.^2).^2 );
end
