function Fst = Rey_Fst(M,biasflag);
%function Fst = Rey_Fst(M,biasflag);
%Returns unbiased Reynolds et al's 2-pop Fst (1983, Genetics 105:767-779)
%  M has vectors of haplotype counts
%  if 'biasflag' is set >0, the biased version of the statistic is returned.
%  if npop>2, I is a vector of pairwise comps taken row-wise from bottom-left triangle.
%  use "distconv" to convert into 2D matrix
%
%This (I think) is the Eq used by Arlequin for 2-pop Fst's
%If Nx=Ny, this is identical to Latter's Fst
% In the unbiased version, as Nx,Ny->inf, terms in 'a' involving Nx, Ny ->0, 
% While the term for b -> fx*hx + fy*hy, where fx and fy are the true relative proportions of X and Y.
% Here, we assume these to be equal, which allows the biased Rey_Fst to equal the biased Latter Fst

if nargin<2, biasflag=0; end

[nhap,npop]=size(M);
N=sum(M);
npairs=npop*(npop-1)/2;

Fst=zeros(npairs,1);
counter=0;
for i=2:npop
for j=1:i-1
  counter=counter+1;
  Nx=N(i); x = M(:,i)./Nx;
  Ny=N(j); y = M(:,j)./Ny;
  hx= 1 - sum(x.*x);
  hy= 1 - sum(y.*y);
  if biasflag>0
     a =   sum((x-y).^2)/2;
     aplusb =  sum((x-y).^2)/2 + (hx+hy)/2;
  else
    a =   sum((x-y).^2)/2 -  (Nx+Ny)*(Nx*hx+Ny*hy)/(2*Nx*Ny*(Nx+Ny-2));
    aplusb =  sum((x-y).^2)/2 +  (2*Nx*Ny-Nx-Ny)*(Nx*hx+Ny*hy)/(2*Nx*Ny*(Nx+Ny-2));
  end

  Fst(counter) = a / aplusb;
end
end
