function Rst = Rst_phi(M,ms,biasflag)
%function Rst = Rst_phi(M,ms,biasflag)
%Returns the AMOVA analogue of Rst defined in Michalakis & Excoffier 1996, Eq(1)-(5)
%Note that their SSD(T) can also be converted as the conventional sum-of-squares
% sum( (x-mean(x))^2 ), summed over all loci
%Likewise their SSD(WP) can be converted the conventional SS, summed over all loci and 
% all pops.
%M is an nhap x npop matrix of haplotype counts in each pop
%ms is an nhap x nloci loci of repeat sizes for each haplotype.
%If biasflag(optional)>0, biased version returned (limit as all n's->infinity)


[nhap,P]=size(M);
[nhap,nloc]=size(ms);
N=sum(M);  NN=sum(N);

sumx_2 = zeros(P,1);    %equals (sum(x)^2)/Ni, then summed over loci for each pop
sumx2 = zeros(P,1);    %equals sum(x^2), then summed over loci for each pop

for i=1:P
  sumx_2(i) = sum( sum( (M(:,i)*ones(1,nloc)).*ms ).^2 ) /N(i);
  sumx2(i) =  sum( sum( (M(:,i)*ones(1,nloc)).*(ms.^2) ) );
end

SSD_T = sum(sumx2) - sum( sum( (sum(M')'*ones(1,nloc)).*ms ).^2 ) /NN;
SSD_WP = sum(sumx2) - sum(sumx_2);
b = NN - sum(N.^2)/NN;

Rst = ((NN-P)*SSD_T - (NN-1)*SSD_WP) / ((NN-P)*SSD_T - (NN-1-b)*SSD_WP);

if nargin>2
if biasflag>0
  Rst = (SSD_T - SSD_WP) / (SSD_T - SSD_WP*sum(N.^2)/NN^2);
end
end

