%File "age_XIb.m" created 16/03/01 by MEW
%This is an M-file for estimating ages of SNP's with linked microsatellites.
%Alter the variables c, u, C, D and P below, then run by starting Matlab and typing "age_XIb".
%If that doesn't work, cut and paste all this text into the Matlab window and hit <RETURN>
%
%This is based on the Factor XI method of Transition matrix modelling.
%However, it improves on the Factor XI method by modelling all MS allele states, not just "ancestral" vs. "non-ancestral".
%The advantage of this is that the method is no longer dependent on c>>u.  Instead, this method is valid for all c/u ratios.
%It is even valid for u-only models (i.e. c=0), but because it looks at the decline in ancestral allele freq over time rather than the increase in variance (i.e. uses less information), we can expect it to have less power than the age_MEW method in cases where the SMM is correct.
%Conversely, if the SMM is not correct we might expect the age_XIb method to be less sensitive to departures from SMM.
%In summary, the age_XIb method features:
%(1) Monitors decline in the freq of the ancestral MS allele, as in the Factor XI method.
%(2) The SSM is modelled completely, using the full freq matrix of all MS alleles.
%(3) 2r alleles above and below the observed range, r, are added, and the SMM is bounded within this range.


c=0.0001		;%Alter this number to your estimate of the per-generation recombination rate
u=0.002		;%Alter this number to your estimate of the per-generation microsat mutation rate

%Alter the vector C below to give the frequencies of each MS repeat size in the Control sample.
%Assuming the derived SNP is at low freq, use non-derived as the "Control" sample
%List the frequencies in order of increasing repeat size.  Add zeros in the middle if necessary.
%Extend or contract the list to fit your observed MS repeat size range.
C=[
0.1
0.2
0.3
0.2
0.1
0.1
];

%Alter the vector D below to give the observed freqs of MS alleles in the derived SNP sample
D=[
0
0
0.2
0.5
0.2
0.1
];

%Alter the vector P below to indicate which MS allele is thought to be ancestral for the derived SNP.
P=[
0
0
0
1
0
0
];



%The MEW program starts now.

%Find obs allele range.
r=length(P);
if (length(C)~=r)|(length(D)~=r), disp('ERROR - vector lengths of C,D & P must match'); end

%Create extra range on either side.
add=2*r;
r5=r + add*2;
fill=zeros(add,1);
seq=(1-add:r5-add)';

%Set some variables.
anc_i = sum( P.*(1:r)' );
if D(anc_i)<C(anc_i)
	disp('WARNING - Fr(Control)>Fr(Derived) for putative ancestral MS allele -');
	disp('   Program may not converge.  Hit <CTRL>+C if program never ends');
end
F_now = D(anc_i);
R = [fill; C; fill]*ones(1,r5);
M = zeros(r5,r5);
	for i=2:r5-1
		M(i-1,i)=0.5;
		M(i+1,i)=0.5;
	end
	M(2,1)=1;  M(r5-1,r5)=1;
Same = (1-c-u).*eye(r5);

%Initialise some variables.
anc_i = anc_i + add;
Pg = [fill; P; fill];
gen = 0;

%main algorithm
while Pg(anc_i)>F_now
	gen=gen+1;

	%Find K, update Pg.
	K = c.*R + u.*M + Same;
	Pg = K*Pg;
end

%Print gen
disp(' '); disp(' ');
disp(['Observed Freq of ancestral MS size in D = ' num2str(F_now)]);
disp(['Number of gens to match obs freq = ' num2str(gen)]);
disp('Type "Pg" to see what final allele distn is expected to look like');
disp('Type "[seq Pg]" to see Pg with MS size in first column');
